@@ -879,11 +879,12 @@ def generate_pybuild(
         if INSTALL_DIRS:
 
             def format_installdir(idir):
-                if idir.comment:
-                    result = f"# {idir.comment}" + "\n" + f"{idir}"
+                comment = idir.comment
+                del idir.comment
+                if comment:
+                    result = f"# {comment}" + "\n" + f"{idir}"
                 else:
                     result = f"{idir}"
-                del idir.comment
                 return result
 
             Mod.append(
