@@ -24,7 +24,7 @@ def main():
         from importmod.main import add_importer_parsers
 
         add_importer_parsers(subparsers)
-    except ImportError:
+    except ModuleNotFoundError:
         pass
 
     scan = subparsers.add_parser(
